FOLDER="ExcelBinOutput"
LANG_FOLDER="TextMap"

# Avatars Data
AVATAR="AvatarExcelConfigData.json" #DONE

# Costume Data
COSTUME="AvatarCostumeExcelConfigData.json" #DONE

# Avatar Skills Data
SKILLDEPOT="AvatarSkillDepotExcelConfigData.json" # Skill Depot #DONE
SKILLS="AvatarSkillExcelConfigData.json" # Skills #DONE
TALENTS="AvatarTalentExcelConfigData.json" # AKA. Constellations #DONE

# Equipment Data
ARTIFACTS="ReliquaryExcelConfigData.json" #DONE
WEAPONS="WeaponExcelConfigData.json" #DONE
ARTIFACTS_SETS="EquipAffixExcelConfigData.json" #DONE

# Fight Props
FIGHT_PROPS="ManualTextMapConfigData.json" #DONE

# Props Map
PROPS_MAP="ProudSkillExcelConfigData.json" #NONE

# Namecards
NAMECARDS="MaterialExcelConfigData.json" #DONE

# Artifact main & sub
ARTIFACT_PROPS_MAIN="ReliquaryMainPropExcelConfigData.json"
ARTIFACT_PROPS_SUB="ReliquaryAffixExcelConfigData.json"


ENVKEY = [
    "AVATAR",
    "SKILLDEPOT",
    "SKILLS",
    "TALENTS",
    "ARTIFACTS",
    "WEAPONS",
    "FIGHT_PROPS",
    "NAMECARDS",
    "ARTIFACTS_SETS",
    "COSTUME",
    "PROPS_MAP",
    "ARTIFACT_PROPS_MAIN",
    "ARTIFACT_PROPS_SUB"
]

LANGKEY = [
    'CHS',
    'CHT',
    'DE',
    'EN',
    'ES',
    'FR',
    'ID',
    'IT',
    'JP',
    'KR',
    'PT',
    'RU',
    'TH',
    'TR',
    'VI'
]

LANGKEY_FILE = [
    'artifact_sets',
    'artifacts',
    'characters',
    'constellations',
    'namecards',
    'skills',
    'weapons'
]