data_prop_json = {
	"101021": {
		"propType": "FIGHT_PROP_HP",
		"efficiency": 0.7998661408903833,
		"position": 1
	},
	"101022": {
		"propType": "FIGHT_PROP_HP",
		"efficiency": 1,
		"position": 2
	},
	"101031": {
		"propType": "FIGHT_PROP_HP_PERCENT",
		"efficiency": 0.8013698223808419,
		"position": 1
	},
	"101032": {
		"propType": "FIGHT_PROP_HP_PERCENT",
		"efficiency": 1,
		"position": 2
	},
	"101051": {
		"propType": "FIGHT_PROP_ATTACK",
		"efficiency": 0.799999951093626,
		"position": 1
	},
	"101052": {
		"propType": "FIGHT_PROP_ATTACK",
		"efficiency": 1,
		"position": 2
	},
	"101061": {
		"propType": "FIGHT_PROP_ATTACK_PERCENT",
		"efficiency": 0.8013698223808419,
		"position": 1
	},
	"101062": {
		"propType": "FIGHT_PROP_ATTACK_PERCENT",
		"efficiency": 1,
		"position": 2
	},
	"101081": {
		"propType": "FIGHT_PROP_DEFENSE",
		"efficiency": 0.800865831025008,
		"position": 1
	},
	"101082": {
		"propType": "FIGHT_PROP_DEFENSE",
		"efficiency": 1,
		"position": 2
	},
	"101091": {
		"propType": "FIGHT_PROP_DEFENSE_PERCENT",
		"efficiency": 0.8021977881396791,
		"position": 1
	},
	"101092": {
		"propType": "FIGHT_PROP_DEFENSE_PERCENT",
		"efficiency": 1,
		"position": 2
	},
	"101201": {
		"propType": "FIGHT_PROP_CRITICAL",
		"efficiency": 0.8041236658084417,
		"position": 1
	},
	"101202": {
		"propType": "FIGHT_PROP_CRITICAL",
		"efficiency": 1,
		"position": 2
	},
	"101221": {
		"propType": "FIGHT_PROP_CRITICAL_HURT",
		"efficiency": 0.7989690355415727,
		"position": 1
	},
	"101222": {
		"propType": "FIGHT_PROP_CRITICAL_HURT",
		"efficiency": 1,
		"position": 2
	},
	"101231": {
		"propType": "FIGHT_PROP_CHARGE_EFFICIENCY",
		"efficiency": 0.8024691315440212,
		"position": 1
	},
	"101232": {
		"propType": "FIGHT_PROP_CHARGE_EFFICIENCY",
		"efficiency": 1,
		"position": 2
	},
	"101241": {
		"propType": "FIGHT_PROP_ELEMENT_MASTERY",
		"efficiency": 0.7993138779408093,
		"position": 1
	},
	"101242": {
		"propType": "FIGHT_PROP_ELEMENT_MASTERY",
		"efficiency": 1,
		"position": 2
	},
	"201021": {
		"propType": "FIGHT_PROP_HP",
		"efficiency": 0.700000010640718,
		"position": 1
	},
	"201022": {
		"propType": "FIGHT_PROP_HP",
		"efficiency": 0.8500697818291011,
		"position": 2
	},
	"201023": {
		"propType": "FIGHT_PROP_HP",
		"efficiency": 1,
		"position": 3
	},
	"201031": {
		"propType": "FIGHT_PROP_HP_PERCENT",
		"efficiency": 0.6995708401537059,
		"position": 1
	},
	"201032": {
		"propType": "FIGHT_PROP_HP_PERCENT",
		"efficiency": 0.8497854200768529,
		"position": 2
	},
	"201033": {
		"propType": "FIGHT_PROP_HP_PERCENT",
		"efficiency": 1,
		"position": 3
	},
	"201051": {
		"propType": "FIGHT_PROP_ATTACK",
		"efficiency": 0.700214117238633,
		"position": 1
	},
	"201052": {
		"propType": "FIGHT_PROP_ATTACK",
		"efficiency": 0.8501070586193165,
		"position": 2
	},
	"201053": {
		"propType": "FIGHT_PROP_ATTACK",
		"efficiency": 1,
		"position": 3
	},
	"201061": {
		"propType": "FIGHT_PROP_ATTACK_PERCENT",
		"efficiency": 0.6995708401537059,
		"position": 1
	},
	"201062": {
		"propType": "FIGHT_PROP_ATTACK_PERCENT",
		"efficiency": 0.8497854200768529,
		"position": 2
	},
	"201063": {
		"propType": "FIGHT_PROP_ATTACK_PERCENT",
		"efficiency": 1,
		"position": 3
	},
	"201081": {
		"propType": "FIGHT_PROP_DEFENSE",
		"efficiency": 0.6996403138377545,
		"position": 1
	},
	"201082": {
		"propType": "FIGHT_PROP_DEFENSE",
		"efficiency": 0.8489208343106637,
		"position": 2
	},
	"201083": {
		"propType": "FIGHT_PROP_DEFENSE",
		"efficiency": 1,
		"position": 3
	},
	"201091": {
		"propType": "FIGHT_PROP_DEFENSE_PERCENT",
		"efficiency": 0.7010309324542161,
		"position": 1
	},
	"201092": {
		"propType": "FIGHT_PROP_DEFENSE_PERCENT",
		"efficiency": 0.8522336763160644,
		"position": 2
	},
	"201093": {
		"propType": "FIGHT_PROP_DEFENSE_PERCENT",
		"efficiency": 1,
		"position": 3
	},
	"201201": {
		"propType": "FIGHT_PROP_CRITICAL",
		"efficiency": 0.7032258250586824,
		"position": 1
	},
	"201202": {
		"propType": "FIGHT_PROP_CRITICAL",
		"efficiency": 0.8516129125293411,
		"position": 2
	},
	"201203": {
		"propType": "FIGHT_PROP_CRITICAL",
		"efficiency": 1,
		"position": 3
	},
	"201221": {
		"propType": "FIGHT_PROP_CRITICAL_HURT",
		"efficiency": 0.7009646525642665,
		"position": 1
	},
	"201222": {
		"propType": "FIGHT_PROP_CRITICAL_HURT",
		"efficiency": 0.8488746119364413,
		"position": 2
	},
	"201223": {
		"propType": "FIGHT_PROP_CRITICAL_HURT",
		"efficiency": 1,
		"position": 3
	},
	"201231": {
		"propType": "FIGHT_PROP_CHARGE_EFFICIENCY",
		"efficiency": 0.6988417152242902,
		"position": 1
	},
	"201232": {
		"propType": "FIGHT_PROP_CHARGE_EFFICIENCY",
		"efficiency": 0.8494208216537456,
		"position": 2
	},
	"201233": {
		"propType": "FIGHT_PROP_CHARGE_EFFICIENCY",
		"efficiency": 1,
		"position": 3
	},
	"201241": {
		"propType": "FIGHT_PROP_ELEMENT_MASTERY",
		"efficiency": 0.6998928470745912,
		"position": 1
	},
	"201242": {
		"propType": "FIGHT_PROP_ELEMENT_MASTERY",
		"efficiency": 0.8499463979833213,
		"position": 2
	},
	"201243": {
		"propType": "FIGHT_PROP_ELEMENT_MASTERY",
		"efficiency": 1,
		"position": 3
	},
	"301021": {
		"propType": "FIGHT_PROP_HP",
		"efficiency": 0.700000010640718,
		"position": 1
	},
	"301022": {
		"propType": "FIGHT_PROP_HP",
		"efficiency": 0.8000000425628723,
		"position": 2
	},
	"301023": {
		"propType": "FIGHT_PROP_HP",
		"efficiency": 0.9000000212814362,
		"position": 3
	},
	"301024": {
		"propType": "FIGHT_PROP_HP",
		"efficiency": 1,
		"position": 4
	},
	"301031": {
		"propType": "FIGHT_PROP_HP_PERCENT",
		"efficiency": 0.699999978712627,
		"position": 1
	},
	"301032": {
		"propType": "FIGHT_PROP_HP_PERCENT",
		"efficiency": 0.800000021287373,
		"position": 2
	},
	"301033": {
		"propType": "FIGHT_PROP_HP_PERCENT",
		"efficiency": 0.9000000106436865,
		"position": 3
	},
	"301034": {
		"propType": "FIGHT_PROP_HP_PERCENT",
		"efficiency": 1,
		"position": 4
	},
	"301051": {
		"propType": "FIGHT_PROP_ATTACK",
		"efficiency": 0.700214117238633,
		"position": 1
	},
	"301052": {
		"propType": "FIGHT_PROP_ATTACK",
		"efficiency": 0.7997858317081389,
		"position": 2
	},
	"301053": {
		"propType": "FIGHT_PROP_ATTACK",
		"efficiency": 0.8993575461776449,
		"position": 3
	},
	"301054": {
		"propType": "FIGHT_PROP_ATTACK",
		"efficiency": 1,
		"position": 4
	},
	"301061": {
		"propType": "FIGHT_PROP_ATTACK_PERCENT",
		"efficiency": 0.699999978712627,
		"position": 1
	},
	"301062": {
		"propType": "FIGHT_PROP_ATTACK_PERCENT",
		"efficiency": 0.800000021287373,
		"position": 2
	},
	"301063": {
		"propType": "FIGHT_PROP_ATTACK_PERCENT",
		"efficiency": 0.9000000106436865,
		"position": 3
	},
	"301064": {
		"propType": "FIGHT_PROP_ATTACK_PERCENT",
		"efficiency": 1,
		"position": 4
	},
	"301081": {
		"propType": "FIGHT_PROP_DEFENSE",
		"efficiency": 0.7002700675271825,
		"position": 1
	},
	"301082": {
		"propType": "FIGHT_PROP_DEFENSE",
		"efficiency": 0.8001800736312134,
		"position": 2
	},
	"301083": {
		"propType": "FIGHT_PROP_DEFENSE",
		"efficiency": 0.9000900368156067,
		"position": 3
	},
	"301084": {
		"propType": "FIGHT_PROP_DEFENSE",
		"efficiency": 1,
		"position": 4
	},
	"301091": {
		"propType": "FIGHT_PROP_DEFENSE_PERCENT",
		"efficiency": 0.7002288624079749,
		"position": 1
	},
	"301092": {
		"propType": "FIGHT_PROP_DEFENSE_PERCENT",
		"efficiency": 0.8009153643849788,
		"position": 2
	},
	"301093": {
		"propType": "FIGHT_PROP_DEFENSE_PERCENT",
		"efficiency": 0.8993134980229961,
		"position": 3
	},
	"301094": {
		"propType": "FIGHT_PROP_DEFENSE_PERCENT",
		"efficiency": 1,
		"position": 4
	},
	"301201": {
		"propType": "FIGHT_PROP_CRITICAL",
		"efficiency": 0.6995708401537059,
		"position": 1
	},
	"301202": {
		"propType": "FIGHT_PROP_CRITICAL",
		"efficiency": 0.7982832806729697,
		"position": 2
	},
	"301203": {
		"propType": "FIGHT_PROP_CRITICAL",
		"efficiency": 0.9012875594807361,
		"position": 3
	},
	"301204": {
		"propType": "FIGHT_PROP_CRITICAL",
		"efficiency": 1,
		"position": 4
	},
	"301221": {
		"propType": "FIGHT_PROP_CRITICAL_HURT",
		"efficiency": 0.6995708401537059,
		"position": 1
	},
	"301222": {
		"propType": "FIGHT_PROP_CRITICAL_HURT",
		"efficiency": 0.8004292397881477,
		"position": 2
	},
	"301223": {
		"propType": "FIGHT_PROP_CRITICAL_HURT",
		"efficiency": 0.9012875594807361,
		"position": 3
	},
	"301224": {
		"propType": "FIGHT_PROP_CRITICAL_HURT",
		"efficiency": 1,
		"position": 4
	},
	"301231": {
		"propType": "FIGHT_PROP_CHARGE_EFFICIENCY",
		"efficiency": 0.6992288170077031,
		"position": 1
	},
	"301232": {
		"propType": "FIGHT_PROP_CHARGE_EFFICIENCY",
		"efficiency": 0.7994858620441655,
		"position": 2
	},
	"301233": {
		"propType": "FIGHT_PROP_CHARGE_EFFICIENCY",
		"efficiency": 0.8997429549635376,
		"position": 3
	},
	"301234": {
		"propType": "FIGHT_PROP_CHARGE_EFFICIENCY",
		"efficiency": 1,
		"position": 4
	},
	"301241": {
		"propType": "FIGHT_PROP_ELEMENT_MASTERY",
		"efficiency": 0.6997855698371146,
		"position": 1
	},
	"301242": {
		"propType": "FIGHT_PROP_ELEMENT_MASTERY",
		"efficiency": 0.7998570238353141,
		"position": 2
	},
	"301243": {
		"propType": "FIGHT_PROP_ELEMENT_MASTERY",
		"efficiency": 0.8999285460018005,
		"position": 3
	},
	"301244": {
		"propType": "FIGHT_PROP_ELEMENT_MASTERY",
		"efficiency": 1,
		"position": 4
	},
	"401021": {
		"propType": "FIGHT_PROP_HP",
		"efficiency": 0.7000000127688611,
		"position": 1
	},
	"401022": {
		"propType": "FIGHT_PROP_HP",
		"efficiency": 0.7999999872311389,
		"position": 2
	},
	"401023": {
		"propType": "FIGHT_PROP_HP",
		"efficiency": 0.9000000255377223,
		"position": 3
	},
	"401024": {
		"propType": "FIGHT_PROP_HP",
		"efficiency": 1,
		"position": 4
	},
	"401031": {
		"propType": "FIGHT_PROP_HP_PERCENT",
		"efficiency": 0.6995708401537059,
		"position": 1
	},
	"401032": {
		"propType": "FIGHT_PROP_HP_PERCENT",
		"efficiency": 0.8004292397881477,
		"position": 2
	},
	"401033": {
		"propType": "FIGHT_PROP_HP_PERCENT",
		"efficiency": 0.9012875594807361,
		"position": 3
	},
	"401034": {
		"propType": "FIGHT_PROP_HP_PERCENT",
		"efficiency": 1,
		"position": 4
	},
	"401051": {
		"propType": "FIGHT_PROP_ATTACK",
		"efficiency": 0.6998714684861824,
		"position": 1
	},
	"401052": {
		"propType": "FIGHT_PROP_ATTACK",
		"efficiency": 0.8001285008687569,
		"position": 2
	},
	"401053": {
		"propType": "FIGHT_PROP_ATTACK",
		"efficiency": 0.899742906327304,
		"position": 3
	},
	"401054": {
		"propType": "FIGHT_PROP_ATTACK",
		"efficiency": 1,
		"position": 4
	},
	"401061": {
		"propType": "FIGHT_PROP_ATTACK_PERCENT",
		"efficiency": 0.6995708401537059,
		"position": 1
	},
	"401062": {
		"propType": "FIGHT_PROP_ATTACK_PERCENT",
		"efficiency": 0.8004292397881477,
		"position": 2
	},
	"401063": {
		"propType": "FIGHT_PROP_ATTACK_PERCENT",
		"efficiency": 0.9012875594807361,
		"position": 3
	},
	"401064": {
		"propType": "FIGHT_PROP_ATTACK_PERCENT",
		"efficiency": 1,
		"position": 4
	},
	"401081": {
		"propType": "FIGHT_PROP_DEFENSE",
		"efficiency": 0.6997840020416457,
		"position": 1
	},
	"401082": {
		"propType": "FIGHT_PROP_DEFENSE",
		"efficiency": 0.800215946464062,
		"position": 2
	},
	"401083": {
		"propType": "FIGHT_PROP_DEFENSE",
		"efficiency": 0.9001079732320311,
		"position": 3
	},
	"401084": {
		"propType": "FIGHT_PROP_DEFENSE",
		"efficiency": 1,
		"position": 4
	},
	"401091": {
		"propType": "FIGHT_PROP_DEFENSE_PERCENT",
		"efficiency": 0.6998285024582124,
		"position": 1
	},
	"401092": {
		"propType": "FIGHT_PROP_DEFENSE_PERCENT",
		"efficiency": 0.799313882035583,
		"position": 2
	},
	"401093": {
		"propType": "FIGHT_PROP_DEFENSE_PERCENT",
		"efficiency": 0.9005145565239961,
		"position": 3
	},
	"401094": {
		"propType": "FIGHT_PROP_DEFENSE_PERCENT",
		"efficiency": 1,
		"position": 4
	},
	"401201": {
		"propType": "FIGHT_PROP_CRITICAL",
		"efficiency": 0.7009646525642665,
		"position": 1
	},
	"401202": {
		"propType": "FIGHT_PROP_CRITICAL",
		"efficiency": 0.8006431216735538,
		"position": 2
	},
	"401203": {
		"propType": "FIGHT_PROP_CRITICAL",
		"efficiency": 0.900321590782841,
		"position": 3
	},
	"401204": {
		"propType": "FIGHT_PROP_CRITICAL",
		"efficiency": 1,
		"position": 4
	},
	"401221": {
		"propType": "FIGHT_PROP_CRITICAL_HURT",
		"efficiency": 0.6993569082725104,
		"position": 1
	},
	"401222": {
		"propType": "FIGHT_PROP_CRITICAL_HURT",
		"efficiency": 0.7990353773817976,
		"position": 2
	},
	"401223": {
		"propType": "FIGHT_PROP_CRITICAL_HURT",
		"efficiency": 0.900321590782841,
		"position": 3
	},
	"401224": {
		"propType": "FIGHT_PROP_CRITICAL_HURT",
		"efficiency": 1,
		"position": 4
	},
	"401231": {
		"propType": "FIGHT_PROP_CHARGE_EFFICIENCY",
		"efficiency": 0.70077217786434,
		"position": 1
	},
	"401232": {
		"propType": "FIGHT_PROP_CHARGE_EFFICIENCY",
		"efficiency": 0.7992277861772604,
		"position": 2
	},
	"401233": {
		"propType": "FIGHT_PROP_CHARGE_EFFICIENCY",
		"efficiency": 0.8996138571302306,
		"position": 3
	},
	"401234": {
		"propType": "FIGHT_PROP_CHARGE_EFFICIENCY",
		"efficiency": 1,
		"position": 4
	},
	"401241": {
		"propType": "FIGHT_PROP_ELEMENT_MASTERY",
		"efficiency": 0.7002681333376832,
		"position": 1
	},
	"401242": {
		"propType": "FIGHT_PROP_ELEMENT_MASTERY",
		"efficiency": 0.8000000204541412,
		"position": 2
	},
	"401243": {
		"propType": "FIGHT_PROP_ELEMENT_MASTERY",
		"efficiency": 0.9002681640188951,
		"position": 3
	},
	"401244": {
		"propType": "FIGHT_PROP_ELEMENT_MASTERY",
		"efficiency": 1,
		"position": 4
	},
	"501021": {
		"propType": "FIGHT_PROP_HP",
		"efficiency": 0.7000167527458159,
		"position": 1
	},
	"501022": {
		"propType": "FIGHT_PROP_HP",
		"efficiency": 0.8,
		"position": 2
	},
	"501023": {
		"propType": "FIGHT_PROP_HP",
		"efficiency": 0.9000167527458159,
		"position": 3
	},
	"501024": {
		"propType": "FIGHT_PROP_HP",
		"efficiency": 1,
		"position": 4
	},
	"501031": {
		"propType": "FIGHT_PROP_HP_PERCENT",
		"efficiency": 0.6998285024582124,
		"position": 1
	},
	"501032": {
		"propType": "FIGHT_PROP_HP_PERCENT",
		"efficiency": 0.799313882035583,
		"position": 2
	},
	"501033": {
		"propType": "FIGHT_PROP_HP_PERCENT",
		"efficiency": 0.9005145565239961,
		"position": 3
	},
	"501034": {
		"propType": "FIGHT_PROP_HP_PERCENT",
		"efficiency": 1,
		"position": 4
	},
	"501051": {
		"propType": "FIGHT_PROP_ATTACK",
		"efficiency": 0.700257036056831,
		"position": 1
	},
	"501052": {
		"propType": "FIGHT_PROP_ATTACK",
		"efficiency": 0.7999999901935807,
		"position": 2
	},
	"501053": {
		"propType": "FIGHT_PROP_ATTACK",
		"efficiency": 0.9002570458632503,
		"position": 3
	},
	"501054": {
		"propType": "FIGHT_PROP_ATTACK",
		"efficiency": 1,
		"position": 4
	},
	"501061": {
		"propType": "FIGHT_PROP_ATTACK_PERCENT",
		"efficiency": 0.6998285024582124,
		"position": 1
	},
	"501062": {
		"propType": "FIGHT_PROP_ATTACK_PERCENT",
		"efficiency": 0.799313882035583,
		"position": 2
	},
	"501063": {
		"propType": "FIGHT_PROP_ATTACK_PERCENT",
		"efficiency": 0.9005145565239961,
		"position": 3
	},
	"501064": {
		"propType": "FIGHT_PROP_ATTACK_PERCENT",
		"efficiency": 1,
		"position": 4
	},
	"501081": {
		"propType": "FIGHT_PROP_DEFENSE",
		"efficiency": 0.6997840617661291,
		"position": 1
	},
	"501082": {
		"propType": "FIGHT_PROP_DEFENSE",
		"efficiency": 0.8000000329563484,
		"position": 2
	},
	"501083": {
		"propType": "FIGHT_PROP_DEFENSE",
		"efficiency": 0.8997840288097807,
		"position": 3
	},
	"501084": {
		"propType": "FIGHT_PROP_DEFENSE",
		"efficiency": 1,
		"position": 4
	},
	"501091": {
		"propType": "FIGHT_PROP_DEFENSE_PERCENT",
		"efficiency": 0.6995884908250543,
		"position": 1
	},
	"501092": {
		"propType": "FIGHT_PROP_DEFENSE_PERCENT",
		"efficiency": 0.7997256775838287,
		"position": 2
	},
	"501093": {
		"propType": "FIGHT_PROP_DEFENSE_PERCENT",
		"efficiency": 0.8998628643426032,
		"position": 3
	},
	"501094": {
		"propType": "FIGHT_PROP_DEFENSE_PERCENT",
		"efficiency": 1,
		"position": 4
	},
	"501201": {
		"propType": "FIGHT_PROP_CRITICAL",
		"efficiency": 0.6992288170077031,
		"position": 1
	},
	"501202": {
		"propType": "FIGHT_PROP_CRITICAL",
		"efficiency": 0.7994858620441655,
		"position": 2
	},
	"501203": {
		"propType": "FIGHT_PROP_CRITICAL",
		"efficiency": 0.8997429549635376,
		"position": 3
	},
	"501204": {
		"propType": "FIGHT_PROP_CRITICAL",
		"efficiency": 1,
		"position": 4
	},
	"501221": {
		"propType": "FIGHT_PROP_CRITICAL_HURT",
		"efficiency": 0.7001287406686748,
		"position": 1
	},
	"501222": {
		"propType": "FIGHT_PROP_CRITICAL_HURT",
		"efficiency": 0.8005148188410904,
		"position": 2
	},
	"501223": {
		"propType": "FIGHT_PROP_CRITICAL_HURT",
		"efficiency": 0.8996139218275844,
		"position": 3
	},
	"501224": {
		"propType": "FIGHT_PROP_CRITICAL_HURT",
		"efficiency": 1,
		"position": 4
	},
	"501231": {
		"propType": "FIGHT_PROP_CHARGE_EFFICIENCY",
		"efficiency": 0.6990740469264689,
		"position": 1
	},
	"501232": {
		"propType": "FIGHT_PROP_CHARGE_EFFICIENCY",
		"efficiency": 0.7993827171139947,
		"position": 2
	},
	"501233": {
		"propType": "FIGHT_PROP_CHARGE_EFFICIENCY",
		"efficiency": 0.8996913298124741,
		"position": 3
	},
	"501234": {
		"propType": "FIGHT_PROP_CHARGE_EFFICIENCY",
		"efficiency": 1,
		"position": 4
	},
	"501241": {
		"propType": "FIGHT_PROP_ELEMENT_MASTERY",
		"efficiency": 0.7001287030773611,
		"position": 1
	},
	"501242": {
		"propType": "FIGHT_PROP_ELEMENT_MASTERY",
		"efficiency": 0.800085802051574,
		"position": 2
	},
	"501243": {
		"propType": "FIGHT_PROP_ELEMENT_MASTERY",
		"efficiency": 0.900042901025787,
		"position": 3
	},
	"501244": {
		"propType": "FIGHT_PROP_ELEMENT_MASTERY",
		"efficiency": 1,
		"position": 4
	}
}